/* $Id: Grid.java,v 1.2 2007/10/24 09:10:39 nito Exp $
 * 
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow.
 * 
 *  Nautica Workflow is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Nautica Workflow; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.commons.swing;

import java.awt.*;

/**
 * グリッド線機能を実現する。
 *
 * @author  Norihiro Itoh(ARGO 21 Corp.)
 * @version $Revision: 1.2 $
 * @since   Nautica Workflow 1.0
 */

public class Grid
{
    /**
     * 指定された座標値を、指定されたグリッド幅で補正する。
     *
     * @param	p	座標値
     * @param	spacing	グリッド幅
     * @return	補正された座標値
     */
    public static Point snap(Point p, int spacing)
    {
		if (spacing <= 0) return null;
		return new Point(
			(p.x + (spacing / 2)) / spacing * spacing,
			(p.y + (spacing / 2)) / spacing * spacing
			);
	}

	/**
	 * 指定されたグラフィックコンポーネントに、指定されたグリッド幅を持つ
	 * グリッド線を描画する。
	 *
	 * @param	c	描画対象のコンポーネント
	 * @param	g	描画対象のグラフィックス
	 * @param	spacing	グリッド幅
	 */
	public static void draw(Component c, Graphics g, Dimension spacing)
	{
		if (spacing == null) return;

		Shape clip = g.getClip();
		Rectangle r = c.getBounds();

		g.setColor(Color.lightGray);

		g.clipRect(0, 0, r.width, r.height);

		for (int i = 0; i < r.height; i += spacing.height)
			g.drawLine(0, i, r.width, i);

		for (int i = 0; i < r.width; i += spacing.width)
			g.drawLine(i, 0, i, r.height);

		g.setClip(clip);
	}

	/**
	 * 指定されたグラフィックコンポーネントに、指定されたグリッド幅を持つ
	 * グリッド線を描画する。
	 *
	 * @param	c	描画対象のコンポーネント
	 * @param	g	描画対象のグラフィックス
	 * @param	spacing	グリッド幅
	 */
	public static void draw(Component c, Graphics g, int spacing)
	{
		if (spacing <= 0) return;

		Shape clip = g.getClip();
		Rectangle r = c.getBounds();

		g.setColor(Color.lightGray);

		g.clipRect(0, 0, r.width, r.height);

		for (int i = 0; i < r.height; i += spacing)
			g.drawLine(0, i, r.width, i);

		for (int i = 0; i < r.width; i += spacing)
			g.drawLine(i, 0, i, r.height);

		g.setClip(clip);
	}

	/**
	 * 指定された矩形範囲に、指定されたグリッド幅を持つ
	 * グリッド線を描画する。
	 *
	 * @param	r	描画対象の矩形範囲
	 * @param	g	描画対象のグラフィックス
	 * @param	spacing	グリッド幅
	 */
	public static void draw(Rectangle r, Graphics g, Dimension spacing)
	{
		if (spacing == null) return;

		g.setColor(Color.lightGray);

		for (int i = r.y; i <= (r.y + r.height); i += spacing.height)
			g.drawLine(r.x, i, r.x + r.width, i);

		for (int i = r.x; i <= (r.x + r.width); i += spacing.width)
			g.drawLine(i, r.y, i, r.y + r.height);
	}

	/**
	 * 指定された矩形範囲に、指定されたグリッド幅を持つ
	 * グリッド線を描画する。
	 *
	 * @param	r	描画対象の矩形範囲
	 * @param	g	描画対象のグラフィックス
	 * @param	spacing	グリッド幅
	 */
	public static void draw(Rectangle r, Graphics g, int spacing)
	{
		if (spacing <= 0) return;

		g.setColor(Color.lightGray);

		for (int i = r.y; i <= (r.y + r.height); i += spacing)
			g.drawLine(r.x, i, r.x + r.width, i);

		for (int i = r.x; i <= (r.x + r.width); i += spacing)
			g.drawLine(i, r.y, i, r.y + r.height);
	}
}
